@@ -1,8 +1,8 @@
-# $rcs = ' $Id: Test.pm,v 2.288 2010-05-20 22:56:04 Martin Exp $ ' ;
+# $rcs = ' $Id: Test.pm,v 2.293 2015-06-06 20:55:31 Martin Exp $ ' ;
 
 =head1 NAME
 
-Test - utilities to aid in testing WWW::Search backends
+WWW::Search::Test - utilities to aid in testing WWW::Search backends
 
 =head1 SYNOPSIS
 
@@ -29,7 +29,6 @@ use Config;
 use Cwd;
 use Data::Dumper;  # for debugging only
 use Date::Manip;
-Date_Init('TZ=-0500');
 use base 'Exporter';
 use File::Path;
 use File::Slurp;
@@ -54,7 +53,7 @@ use vars qw( @EXPORT );
 
 use vars qw( $VERSION $bogus_query $websearch );
 
-$VERSION = do { my @r = (q$Revision: 2.288 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.293 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 $bogus_query = "Bogus" . $$ . "NoSuchWord" . time;
 
 ($MODE_DUMMY, $MODE_INTERNAL, $MODE_EXTERNAL, $MODE_UPDATE) = qw(dummy internal external update);
@@ -690,7 +689,7 @@ Same as tm_run_test, but does NOT check the approximate_result_count.
 
 sub tm_run_test_no_approx
   {
-  &_tm_run_test(@_, 0);
+  _tm_run_test(@_, 0);
   } # tm_run_test_no_approx
 
 =head2 count_results
@@ -813,7 +812,7 @@ sub test_most_results
   my %hioExemplar;
   my %hiiFailed;
   # Create a bit vector large enough to hold one bit for each test:
-  my $oV = new Bit::Vector($iCount-1);
+  my $oV = new Bit::Vector($iCount);
   # Turn on all the bits (we will turn off bits when tests fail):
   $oV->Fill;
   my $iVall = $oV->to_Dec;
@@ -824,6 +823,7 @@ sub test_most_results
     {
     # print STDERR " DDD ra is ", Dumper($ra);
     my ($sField, $sCmp, $sValue, $sDesc) = @$ra;
+    $sDesc ||= qq{test #$iTest};
     my $sCode;
     if ($sCmp eq 'like')
       {
@@ -839,21 +839,20 @@ sub test_most_results
       } # if
     else
       {
-      $sCode = "(\$oResult->$sField $sCmp '$sValue')";
+      $sCode = "(\$oResult->$sField $sCmp $sValue)";
       }
     $sCode = <<"ENDCODE";
 if (! $sCode)
   {
   \$oV->Bit_Off($iTest);
-  \$hiiFailed{'$sField'}++;
+  \$hiiFailed{'$sDesc'}++;
   } # if
 ENDCODE
     $sCodeAll .= $sCode;
     $iTest++;
     } # foreach TEST
   $sCodeAll .= "1;\n";
-  # $sCodeAll =~ s{/\(\?-xism:}{/(}g;
-  # print STDERR " DDD the test is ==$sCodeAll==\n";
+  # print STDERR " DDD the test is ===$sCodeAll===\n";
  RESULT:
   foreach my $oResult ($oSearch->results())
     {
@@ -872,9 +871,21 @@ ENDCODE
       # At least one of the bits got turned off (i.e. a test failed):
       $hioExemplar{$iV} = $oResult;
       $iAnyFailed++;
+      # For debugging:
+      # print STDERR Dumper($oResult);
+      # last RESULT;
       } # if
     } # foreach RESULT
   ok($iResult, qq{got more than zero results ($iResult, to be exact)});
+  # Now make sure all the sub-tests passed at least N% of the time.
+  # We only need to look at sub-tests that had any failures (sub-tests
+  # with no failures are 100% correct, so there's no need to check
+  # them 8-)
+  while (my ($sItem, $iFailed) = each %hiiFailed)
+    {
+    my $fPctFailed = ($iFailed / $iResult);
+    ok($fPctFailed < (1 - $fPct), sprintf(qq{%0.1f%% of '%s' tests failed}, $fPctFailed * 100, $sItem));
+    } # while
   if ($iAnyFailed)
     {
     Test::More::diag(" Here are result(s) that exemplify test failure(s):");
@@ -883,11 +894,6 @@ ENDCODE
       Test::More::diag(Dumper($oResult));
       } # while
     } # if
-  while (my ($sItem, $iFailed) = each %hiiFailed)
-    {
-    my $fPctFailed = ($iFailed / $iResult);
-    ok($fPctFailed < (1 - $fPct), sprintf(qq{%0.1f%% of %s tests failed}, $fPctFailed * 100, $sItem));
-    } # while
   } # test_most_results
 
 1;
